import * as React from "react";
import * as PropTypes from "prop-types";
import { Column, Props as ColumnProps } from "./Column";
import { ChildrenOf } from "../utils/types";
import "./Table.less";
export declare type SortDirection = "asc" | "desc";
export interface SortState {
    columnID?: string;
    direction?: SortDirection;
}
export declare type PageRangeSize = 1 | 3 | 5 | 7 | 9;
export interface Props {
    children?: ChildrenOf<typeof Column>;
    className?: string;
    data?: any[];
    filter?: Function;
    fixed?: boolean;
    initialPage?: number;
    initialSortState?: SortState;
    firstSortDirection?: SortDirection;
    onPageChange?: Function;
    onRowClick?: Function;
    onRowMouseOver?: (e: any, rowID: any, rowData: any) => void;
    onSortChange?: Function;
    onViewChange?: Function;
    pageSize?: number;
    paginated?: boolean;
    visiblePageRangeSize?: PageRangeSize;
    rowIDFn: Function;
    rowClassNameFn?: Function;
    noDataContent?: React.ReactNode;
    lazy?: boolean;
    getData?: Function;
    numRows?: number;
}
interface State {
    currentPage: number;
    sortState: SortState;
    lazyPages: any[];
    pageLoading: boolean;
    allLoaded: boolean;
}
export declare const DEFAULT_VISIBLE_PAGE_RANGE_SIZE = 5;
export declare const cssClass: {
    BODY: string;
    CLICKABLE_ROW: string;
    FIXED: string;
    NO_DATA: string;
    NO_DATA_CONTENT: string;
    ROW: string;
    TABLE: string;
};
export declare class Table extends React.Component<Props, State> {
    static propTypes: {
        children: PropTypes.Requireable<unknown[]>;
        className: PropTypes.Requireable<string>;
        data: PropTypes.Requireable<any[]>;
        filter: PropTypes.Requireable<(...args: any[]) => any>;
        fixed: PropTypes.Requireable<boolean>;
        initialPage: {
            (props: any, propName: any, componentName: any): Error;
            isRequired(props: any, propName: any, componentName: any): Error;
        };
        initialSortState: PropTypes.Requireable<PropTypes.InferProps<{
            columnID: PropTypes.Requireable<string>;
            direction: PropTypes.Requireable<"desc" | "asc">;
        }>>;
        firstSortDirection: PropTypes.Requireable<"desc" | "asc">;
        onPageChange: PropTypes.Requireable<(...args: any[]) => any>;
        onRowClick: PropTypes.Requireable<(...args: any[]) => any>;
        onRowMouseOver: PropTypes.Requireable<(...args: any[]) => any>;
        onSortChange: PropTypes.Requireable<(...args: any[]) => any>;
        onViewChange: PropTypes.Requireable<(...args: any[]) => any>;
        pageSize: PropTypes.Requireable<number>;
        paginated: PropTypes.Requireable<boolean>;
        visiblePageRangeSize: PropTypes.Requireable<number>;
        rowIDFn: PropTypes.Validator<(...args: any[]) => any>;
        rowClassNameFn: PropTypes.Requireable<(...args: any[]) => any>;
        noDataContent: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        lazy: PropTypes.Requireable<boolean>;
        getData: PropTypes.Requireable<(...args: any[]) => any>;
        numRows: PropTypes.Requireable<number>;
    };
    static defaultProps: {
        onPageChange: () => void;
        onSortChange: () => void;
        pageSize: number;
        visiblePageRangeSize: number;
        firstSortDirection: "asc";
    };
    static Column: React.FunctionComponent<ColumnProps>;
    static sortDirection: {
        readonly ASCENDING: "asc";
        readonly DESCENDING: "desc";
    };
    constructor(props: Props);
    componentDidMount(): void;
    componentWillUnmount(): void;
    private _epoch;
    private _isMounted;
    /**
     * @param {number} page - 1-based index of the page to select.
     */
    setCurrentPage(page: any): Promise<void>;
    _fetchLazy(pageIdx: any): Promise<void>;
    /**
     * Resets all lazily-loaded data. Call this if you change the backing data
     * behind the `getData` function (i.e. apply a search filter).
     */
    lazyReset(): void;
    _getColumn(columnID: any): React.ReactElement<ColumnProps, string | ((props: any) => React.ReactElement<any, any>) | (new (props: any) => React.Component<any, any, any>)>;
    _toggleSort(columnID: any): void;
    _getSynchronousData(): {
        displayedData: any;
        numPages: number;
    };
    _getLazyData(): {
        displayedData: any;
        numPages: any;
    };
    _getDisplayedData(): {
        displayedData: any;
        numPages: any;
    };
    render(): JSX.Element;
}
export {};
